@@ -24,6 +24,9 @@ class StartVerbatimBox(CompilerDirective):
     def __init__(self):
         super().__init__(["StartVerbatim"])
 
+    def counterpart(self) -> CompilerDirective:
+        return EndVerbatimBox()
+
     def to_ir(self, *args, **kwargs):
         return ir.StartVerbatimBox.construct()
 
@@ -37,5 +40,8 @@ class EndVerbatimBox(CompilerDirective):
     def __init__(self):
         super().__init__(["EndVerbatim"])
 
+    def counterpart(self) -> CompilerDirective:
+        return StartVerbatimBox()
+
     def to_ir(self, *args, **kwargs):
         return ir.EndVerbatimBox.construct()
