@@ -19,7 +19,6 @@ from sympy import Float
 import braket.ir.jaqcd as ir
 from braket.circuits import circuit
 from braket.circuits.angled_gate import AngledGate
-from braket.circuits.free_parameter import FreeParameter
 from braket.circuits.free_parameter_expression import FreeParameterExpression
 from braket.circuits.gate import Gate
 from braket.circuits.instruction import Instruction
@@ -490,10 +489,10 @@ class Rx(AngledGate):
     """X-axis rotation gate.
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: Union[FreeParameter, float]):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -513,27 +512,18 @@ class Rx(AngledGate):
         return 1
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            **kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.Rx: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
     @circuit.subroutine(register=True)
-    def rx(target: QubitInput, angle: Union[FreeParameter, float]) -> Iterable[Instruction]:
+    def rx(
+        target: QubitInput, angle: Union[FreeParameterExpression, float]
+    ) -> Iterable[Instruction]:
         """Registers this function into the circuit class.
 
         Args:
             target (Qubit or int): Target qubit index.
-            angle (Union[FreeParameter, float]): Angle in radians.
+            angle (Union[FreeParameterExpression, float]): Angle in radians.
 
         Returns:
             Iterable[Instruction]: Rx instruction.
@@ -551,10 +541,10 @@ class Ry(AngledGate):
     """Y-axis rotation gate.
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: Union[FreeParameter, float]):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -574,27 +564,18 @@ class Ry(AngledGate):
         return 1
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            **kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.Ry: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
     @circuit.subroutine(register=True)
-    def ry(target: QubitInput, angle: Union[FreeParameter, float]) -> Iterable[Instruction]:
+    def ry(
+        target: QubitInput, angle: Union[FreeParameterExpression, float]
+    ) -> Iterable[Instruction]:
         """Registers this function into the circuit class.
 
         Args:
             target (Qubit or int): Target qubit index.
-            angle (Union[FreeParameter, float]): Angle in radians.
+            angle (Union[FreeParameterExpression, float]): Angle in radians.
 
         Returns:
             Iterable[Instruction]: Ry instruction.
@@ -612,10 +593,10 @@ class Rz(AngledGate):
     """Z-axis rotation gate.
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: Union[FreeParameter, float]):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -631,17 +612,6 @@ class Rz(AngledGate):
         )
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            **kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.Rz: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -650,12 +620,14 @@ class Rz(AngledGate):
 
     @staticmethod
     @circuit.subroutine(register=True)
-    def rz(target: QubitInput, angle: Union[FreeParameter, float]) -> Iterable[Instruction]:
+    def rz(
+        target: QubitInput, angle: Union[FreeParameterExpression, float]
+    ) -> Iterable[Instruction]:
         """Registers this function into the circuit class.
 
         Args:
             target (Qubit or int): Target qubit index.
-            angle (Union[FreeParameter, float]): angle in radians.
+            angle (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Iterable[Instruction]: Rz instruction.
@@ -673,10 +645,10 @@ class PhaseShift(AngledGate):
     """Phase shift gate.
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: float):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -690,17 +662,6 @@ class PhaseShift(AngledGate):
         return np.array([[1.0, 0.0], [0.0, np.exp(1j * self.angle)]], dtype=complex)
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            **kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.PhaseShift: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -709,12 +670,14 @@ class PhaseShift(AngledGate):
 
     @staticmethod
     @circuit.subroutine(register=True)
-    def phaseshift(target: QubitInput, angle: Union[FreeParameter, float]) -> Iterable[Instruction]:
+    def phaseshift(
+        target: QubitInput, angle: Union[FreeParameterExpression, float]
+    ) -> Iterable[Instruction]:
         """Registers this function into the circuit class.
 
         Args:
             target (Qubit or int): Target qubit index.
-            angle (Union[FreeParameter, float]): angle in radians.
+            angle (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Iterable[Instruction]: PhaseShift instruction.
@@ -879,10 +842,10 @@ class PSwap(AngledGate):
     """PSwap gate.
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: float):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -907,17 +870,6 @@ class PSwap(AngledGate):
         )
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.PSwap: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -932,7 +884,7 @@ class PSwap(AngledGate):
         Args:
             target1 (Qubit or int): Target qubit 1 index.
             target2 (Qubit or int): Target qubit 2 index.
-            angle (Union[FreeParameter, float]): angle in radians.
+            angle (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Instruction: PSwap instruction.
@@ -952,10 +904,10 @@ class XY(AngledGate):
     Reference: https://arxiv.org/abs/1912.04424v1
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: float):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -982,17 +934,6 @@ class XY(AngledGate):
         )
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.XY: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -1002,14 +943,14 @@ class XY(AngledGate):
     @staticmethod
     @circuit.subroutine(register=True)
     def xy(
-        target1: QubitInput, target2: QubitInput, angle: Union[FreeParameter, float]
+        target1: QubitInput, target2: QubitInput, angle: Union[FreeParameterExpression, float]
     ) -> Instruction:
         """Registers this function into the circuit class.
 
         Args:
             target1 (Qubit or int): Target qubit 1 index.
             target2 (Qubit or int): Target qubit 2 index.
-            angle (Union[FreeParameter, float]): angle in radians.
+            angle (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Instruction: XY instruction.
@@ -1027,10 +968,10 @@ class CPhaseShift(AngledGate):
     """Controlled phase shift gate.
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: float):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -1044,17 +985,6 @@ class CPhaseShift(AngledGate):
         return np.diag([1.0, 1.0, 1.0, np.exp(1j * self.angle)])
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            **kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.CPhaseShift: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -1064,14 +994,14 @@ class CPhaseShift(AngledGate):
     @staticmethod
     @circuit.subroutine(register=True)
     def cphaseshift(
-        control: QubitInput, target: QubitInput, angle: Union[FreeParameter, float]
+        control: QubitInput, target: QubitInput, angle: Union[FreeParameterExpression, float]
     ) -> Instruction:
         """Registers this function into the circuit class.
 
         Args:
             control (Qubit or int): Control qubit index.
             target (Qubit or int): Target qubit index.
-            angle (Union[FreeParameter, float]): angle in radians.
+            angle (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Instruction: CPhaseShift instruction.
@@ -1089,10 +1019,10 @@ class CPhaseShift00(AngledGate):
     """Controlled phase shift gate for phasing the \\|00> state.
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: float):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -1106,17 +1036,6 @@ class CPhaseShift00(AngledGate):
         return np.diag([np.exp(1j * self.angle), 1.0, 1.0, 1.0])
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            **kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.CPhaseShift00: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -1126,14 +1045,14 @@ class CPhaseShift00(AngledGate):
     @staticmethod
     @circuit.subroutine(register=True)
     def cphaseshift00(
-        control: QubitInput, target: QubitInput, angle: Union[FreeParameter, float]
+        control: QubitInput, target: QubitInput, angle: Union[FreeParameterExpression, float]
     ) -> Instruction:
         """Registers this function into the circuit class.
 
         Args:
             control (Qubit or int): Control qubit index.
             target (Qubit or int): Target qubit index.
-            angle (Union[FreeParameter, float]): angle in radians.
+            angle (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Instruction: CPhaseShift00 instruction.
@@ -1151,10 +1070,10 @@ class CPhaseShift01(AngledGate):
     """Controlled phase shift gate for phasing the \\|01> state.
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: float):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -1168,17 +1087,6 @@ class CPhaseShift01(AngledGate):
         return np.diag([1.0, np.exp(1j * self.angle), 1.0, 1.0])
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            **kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.CPhaseShift01: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -1188,14 +1096,14 @@ class CPhaseShift01(AngledGate):
     @staticmethod
     @circuit.subroutine(register=True)
     def cphaseshift01(
-        control: QubitInput, target: QubitInput, angle: Union[FreeParameter, float]
+        control: QubitInput, target: QubitInput, angle: Union[FreeParameterExpression, float]
     ) -> Instruction:
         """Registers this function into the circuit class.
 
         Args:
             control (Qubit or int): Control qubit index.
             target (Qubit or int): Target qubit index.
-            angle (Union[FreeParameter, float]): angle in radians.
+            angle (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Instruction: CPhaseShift01 instruction.
@@ -1213,10 +1121,10 @@ class CPhaseShift10(AngledGate):
     """Controlled phase shift gate for phasing the \\|10> state.
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: float):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -1230,17 +1138,6 @@ class CPhaseShift10(AngledGate):
         return np.diag([1.0, 1.0, np.exp(1j * self.angle), 1.0])
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            **kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.CPhaseShift10: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -1250,14 +1147,14 @@ class CPhaseShift10(AngledGate):
     @staticmethod
     @circuit.subroutine(register=True)
     def cphaseshift10(
-        control: QubitInput, target: QubitInput, angle: Union[FreeParameter, float]
+        control: QubitInput, target: QubitInput, angle: Union[FreeParameterExpression, float]
     ) -> Instruction:
         """Registers this function into the circuit class.
 
         Args:
             control (Qubit or int): Control qubit index.
             target (Qubit or int): Target qubit index.
-            angle (Union[FreeParameter, float]): angle in radians.
+            angle (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Instruction: CPhaseShift10 instruction.
@@ -1460,10 +1357,10 @@ class XX(AngledGate):
     Reference: https://arxiv.org/abs/1707.06356
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: float):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -1490,17 +1387,6 @@ class XX(AngledGate):
         )
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            **kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.XX: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -1510,14 +1396,14 @@ class XX(AngledGate):
     @staticmethod
     @circuit.subroutine(register=True)
     def xx(
-        target1: QubitInput, target2: QubitInput, angle: Union[FreeParameter, float]
+        target1: QubitInput, target2: QubitInput, angle: Union[FreeParameterExpression, float]
     ) -> Instruction:
         """Registers this function into the circuit class.
 
         Args:
             target1 (Qubit or int): Target qubit 1 index.
             target2 (Qubit or int): Target qubit 2 index.
-            angle (Union[FreeParameter, float]): angle in radians.
+            angle (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Instruction: XX instruction.
@@ -1537,10 +1423,10 @@ class YY(AngledGate):
     Reference: https://arxiv.org/abs/1707.06356
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: float):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -1567,17 +1453,6 @@ class YY(AngledGate):
         )
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            **kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.YY: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -1587,14 +1462,14 @@ class YY(AngledGate):
     @staticmethod
     @circuit.subroutine(register=True)
     def yy(
-        target1: QubitInput, target2: QubitInput, angle: Union[FreeParameter, float]
+        target1: QubitInput, target2: QubitInput, angle: Union[FreeParameterExpression, float]
     ) -> Instruction:
         """Registers this function into the circuit class.
 
         Args:
             target1 (Qubit or int): Target qubit 1 index.
             target2 (Qubit or int): Target qubit 2 index.
-            angle (Union[FreeParameter, float]): angle in radians.
+            angle (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Instruction: YY instruction.
@@ -1614,10 +1489,10 @@ class ZZ(AngledGate):
     Reference: https://arxiv.org/abs/1707.06356
 
     Args:
-        angle (Union[FreeParameter, float]): angle in radians.
+        angle (Union[FreeParameterExpression, float]): angle in radians.
     """
 
-    def __init__(self, angle: float):
+    def __init__(self, angle: Union[FreeParameterExpression, float]):
         super().__init__(
             angle=angle,
             qubit_count=None,
@@ -1642,17 +1517,6 @@ class ZZ(AngledGate):
         )
 
     def bind_values(self, **kwargs):
-        """
-        Takes in parameters and attempts to assign them to values.
-
-        Args:
-            **kwargs: The parameters that are being assigned.
-
-        Returns:
-            Gate.ZZ: A new Gate of the same type with the requested
-            parameters bound.
-
-        """
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -1662,14 +1526,14 @@ class ZZ(AngledGate):
     @staticmethod
     @circuit.subroutine(register=True)
     def zz(
-        target1: QubitInput, target2: QubitInput, angle: Union[FreeParameter, float]
+        target1: QubitInput, target2: QubitInput, angle: Union[FreeParameterExpression, float]
     ) -> Instruction:
         """Registers this function into the circuit class.
 
         Args:
             target1 (Qubit or int): Target qubit 1 index.
             target2 (Qubit or int): Target qubit 2 index.
-            angle (Union[FreeParameter, float]): angle in radians.
+            angle (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Instruction: ZZ instruction.
@@ -1869,13 +1733,13 @@ class Unitary(Gate):
 Gate.register_gate(Unitary)
 
 
-def angled_ascii_characters(gate: str, angle: Union[FreeParameter, float]) -> str:
+def angled_ascii_characters(gate: str, angle: Union[FreeParameterExpression, float]) -> str:
     """
     Generates a formatted ascii representation of an angled gate.
 
     Args:
         gate (str): The name of the gate.
-        angle (Union[FreeParameter, float]): The angle for the gate.
+        angle (Union[FreeParameterExpression, float]): The angle for the gate.
 
     Returns:
         str: Returns the ascii representation for an angled gate.
@@ -1894,7 +1758,6 @@ def get_angle(self, **kwargs):
 
     Returns:
         A new gate of the type of the AngledGate originally used with all angles updated.
-
     """
     new_angle = (
         self.angle.subs(kwargs) if isinstance(self.angle, FreeParameterExpression) else self.angle
