@@ -1,4 +1,4 @@
-# Copyright 2019-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -20,7 +20,7 @@ class Operator(ABC):
     @property
     @abstractmethod
     def name(self) -> str:
-        """str: The operator name."""
+        """str: The name of the operator."""
 
     @abstractmethod
     def to_ir(self, *args, **kwargs):
