@@ -50,6 +50,18 @@ def test_angle_setter(angled_gate):
     angled_gate.angle = 0.14
 
 
+def test_adjoint(angled_gate):
+    assert angled_gate.adjoint() == [AngledGate(angle=-0.15, qubit_count=1, ascii_symbols=["foo"])]
+
+
+def test_adjoint_parameterized():
+    theta = FreeParameter("theta")
+    angled_gate = AngledGate(angle=(theta + 1), qubit_count=1, ascii_symbols=["foo"])
+    assert angled_gate.adjoint() == [
+        AngledGate(angle=-(theta + 1), qubit_count=1, ascii_symbols=["foo"])
+    ]
+
+
 def test_equality(angled_gate):
     gate = AngledGate(angle=0.15, qubit_count=1, ascii_symbols=["bar"])
     other_gate = AngledGate(angle=0.3, qubit_count=1, ascii_symbols=["foo"])
